==> zio-aws-rekognition_2.12-5.17.150.1-sources.jar: zio/aws/rekognition/model/StopProjectVersionResponse.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StopProjectVersionResponse(
    status: Option[zio.aws.rekognition.model.ProjectVersionStatus] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse = {
    import StopProjectVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
      .builder()
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.rekognition.model.StopProjectVersionResponse.ReadOnly =
    zio.aws.rekognition.model.StopProjectVersionResponse.wrap(buildAwsValue())
}
object StopProjectVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.StopProjectVersionResponse =
      zio.aws.rekognition.model
        .StopProjectVersionResponse(status.map(value => value))
    def status: Option[zio.aws.rekognition.model.ProjectVersionStatus]
    def getStatus
        : ZIO[Any, AwsError, zio.aws.rekognition.model.ProjectVersionStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
  ) extends zio.aws.rekognition.model.StopProjectVersionResponse.ReadOnly {
    override val status
        : Option[zio.aws.rekognition.model.ProjectVersionStatus] = scala
      .Option(impl.status())
      .map(value => zio.aws.rekognition.model.ProjectVersionStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
  ): zio.aws.rekognition.model.StopProjectVersionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.17.178.1-sources.jar: zio/aws/rekognition/model/StopProjectVersionResponse.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StopProjectVersionResponse(
    status: Optional[zio.aws.rekognition.model.ProjectVersionStatus] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse = {
    import StopProjectVersionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
      .builder()
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.rekognition.model.StopProjectVersionResponse.ReadOnly =
    zio.aws.rekognition.model.StopProjectVersionResponse.wrap(buildAwsValue())
}
object StopProjectVersionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.StopProjectVersionResponse =
      zio.aws.rekognition.model
        .StopProjectVersionResponse(status.map(value => value))
    def status: Optional[zio.aws.rekognition.model.ProjectVersionStatus]
    def getStatus
        : ZIO[Any, AwsError, zio.aws.rekognition.model.ProjectVersionStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
  ) extends zio.aws.rekognition.model.StopProjectVersionResponse.ReadOnly {
    override val status
        : Optional[zio.aws.rekognition.model.ProjectVersionStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.rekognition.model.ProjectVersionStatus.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.StopProjectVersionResponse
  ): zio.aws.rekognition.model.StopProjectVersionResponse.ReadOnly =
    new Wrapper(impl)
}
